@@ -24,8 +24,6 @@
 
 #include <QApplication>
 #include <QCryptographicHash>
-#include <QDBusConnectionInterface>
-#include <QDBusReply>
 #include <QDir>
 #include <QInputDialog>
 #include <QTimer>
@@ -125,23 +123,21 @@ bool KateSessionManager::activateSession(KateSession::Ptr session, const bool cl
 
     if (!session->isAnonymous()) {
         // check if the requested session is already open in another instance
-        KateRunningInstanceMap instances;
-        if (!fillinRunningKateAppInstances(&instances)) {
-            KMessageBox::error(nullptr, i18n("Internal error: there is more than one instance open for a given session."));
-            return false;
-        }
-
-        if (instances.find(session->name()) != instances.end()) {
-            if (KMessageBox::questionTwoActions(
-                    nullptr,
-                    i18n("Session '%1' is already opened in another Kate instance. Switch to that or reopen in this instance?", session->name()),
-                    QString(),
-                    KGuiItem(i18nc("@action:button", "Switch to Instance"), QStringLiteral("window")),
-                    KGuiItem(i18nc("@action:button", "Reopen"), QStringLiteral("document-open")),
-                    QStringLiteral("katesessionmanager_switch_instance"))
-                == KMessageBox::PrimaryAction) {
-                instances[session->name()].dbus_if->call(QStringLiteral("activate"));
-                return false;
+        const auto instances = fillinRunningKateAppInstances();
+        for (const auto &instance : instances) {
+            if (session->name() == instance.sessionName) {
+                if (KMessageBox::questionTwoActions(
+                        nullptr,
+                        i18n("Session '%1' is already opened in another Kate instance. Switch to that or reopen in this instance?", session->name()),
+                        QString(),
+                        KGuiItem(i18nc("@action:button", "Switch to Instance"), QStringLiteral("window")),
+                        KGuiItem(i18nc("@action:button", "Reopen"), QStringLiteral("document-open")),
+                        QStringLiteral("katesessionmanager_switch_instance"))
+                    == KMessageBox::PrimaryAction) {
+                    instance.dbus_if->call(QStringLiteral("activate"));
+                    return false;
+                }
+                break;
             }
         }
     }
@@ -563,35 +559,17 @@ void KateSessionManager::sessionManage()
 
 bool KateSessionManager::sessionIsActive(const QString &session)
 {
-    // Try to avoid unneed action
+    // first check the current instance, that is skipped below
     if (activeSession() && activeSession()->name() == session) {
         return true;
     }
 
-    QDBusConnectionInterface *i = QDBusConnection::sessionBus().interface();
-    if (!i) {
-        return false;
-    }
-
-    // look up all running kate instances and there sessions
-    QDBusReply<QStringList> servicesReply = i->registeredServiceNames();
-    QStringList services;
-    if (servicesReply.isValid()) {
-        services = servicesReply.value();
-    }
-
-    for (const QString &s : qAsConst(services)) {
-        if (!s.startsWith(QLatin1String("org.kde.kate-"))) {
-            continue;
-        }
-
-        KateRunningInstanceInfo rii(s);
-        if (rii.valid && rii.sessionName == session) {
-            return true;
-        }
-    }
-
-    return false;
+    // check if the requested session is open in another instance
+    const auto instances = fillinRunningKateAppInstances();
+    const auto it = std::find_if(instances.cbegin(), instances.cend(), [&session](const auto &instance) {
+        return instance.sessionName == session;
+    });
+    return it != instances.end();
 }
 
 QString KateSessionManager::anonymousSessionFile() const
